@@ -6,7 +6,6 @@ from .message_created import MessageCreated, MessageCreatedData
 from .session_created import SessionCreated, SessionCreatedData
 from .session_finished import SessionFinished, SessionFinishedData
 from .session_transferred import SessionTransferred, SessionTransferredData
-from .app_connection import AppConnection
 from .app_connection_created import AppConnectionCreated, AppConnectionCreatedData
 
 
@@ -27,4 +26,7 @@ __all__ = [
     "SessionCreatedData",
     "SessionFinishedData",
     "SessionTransferredData",
+
+    "AppConnectionCreated",
+    "AppConnectionCreatedData",
 ] 
\ No newline at end of file
